@@ -895,12 +895,12 @@ class Irc(IrcCommandDispatcher):
 
     def _setNonResettingVariables(self):
         # Configuration stuff.
-        self.nick = conf.supybot.nick()
-        network_nick = conf.supybot.networks.get(self.network).nick()
-        if network_nick != '':
-            self.nick = network_nick
-        self.user = conf.supybot.user()
-        self.ident = conf.supybot.ident()
+        def get_value(name):
+            return getattr(conf.supybot.networks.get(self.network), name)() or \
+                getattr(conf.supybot, name)()
+        self.nick = get_value('nick')
+        self.user = get_value('user')
+        self.ident = get_value('ident')
         self.alternateNicks = conf.supybot.nick.alternates()[:]
         self.password = conf.supybot.networks.get(self.network).password()
         self.sasl_username = \
@@ -939,9 +939,9 @@ class Irc(IrcCommandDispatcher):
                     ]).encode('utf-8')).decode('utf-8')
                     log.debug('Sending CAP REQ command, requesting capability \'sasl\'.')
                     self.queueMsg(ircmsgs.IrcMsg(command="CAP", args=('REQ', 'sasl')))
-                    log.debug('Sending AUTHENTICATE command, using mechanism PLAIN.')
+                    log.debug('Using SASL mechanism PLAIN.')
                     self.queueMsg(ircmsgs.IrcMsg(command="AUTHENTICATE", args=('PLAIN',)))
-                    log.info('Sending AUTHENTICATE command, not logging the password.')
+                    log.info('Authenticating using SASL.')
                     self.queueMsg(ircmsgs.IrcMsg(command="AUTHENTICATE", args=(auth_string,)))
             if self.password:
                 log.info('Sending PASS command, not logging the password.')
@@ -954,14 +954,29 @@ class Irc(IrcCommandDispatcher):
 
     def do903(self, msg):
         log.info('%s: SASL authentication successful' % self.network)
-        log.debug('Sending CAP END command.')
-        self.queueMsg(ircmsgs.IrcMsg(command="CAP", args=('END',)))
+        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
 
     def do904(self, msg):
         log.warning('%s: SASL authentication failed' % self.network)
-        log.debug('Aborting authentication.')
-        log.debug('Sending CAP END command.')
-        self.queueMsg(ircmsgs.IrcMsg(command="CAP", args=('END',)))
+        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
+
+    def do905(self, msg):
+        log.warning(('%s: SASL authentication failed because your username '
+                     'or password is too long.') % self.network)
+        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
+
+    def do906(self, msg):
+        log.warning('%s: SASL authentication aborted' % self.network)
+        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
+
+    def do907(self, msg):
+        log.warning(('%s: Attempted SASL authentication when we were already '
+                     'authenticated.') % self.network)
+        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
+
+    def do908(self, msg):
+        log.info('%s: Supported SASL mechanisms: %s' %
+                 (self.network, msg.args[1]))
 
     def _getNextNick(self):
         if self.alternateNicks:
