@@ -81,8 +81,9 @@ class IrcMsg(object):
     # data.  Goodbye, __slots__.
     # On second thought, let's use methods for tagging.
     __slots__ = ('args', 'command', 'host', 'nick', 'prefix', 'user',
-                 '_hash', '_str', '_repr', '_len', 'tags')
-    def __init__(self, s='', command='', args=(), prefix='', msg=None):
+                 '_hash', '_str', '_repr', '_len', 'tags', 'reply_env')
+    def __init__(self, s='', command='', args=(), prefix='', msg=None,
+            reply_env=None):
         assert not (msg and s), 'IrcMsg.__init__ cannot accept both s and msg'
         if not s and not command and not msg:
             raise MalformedIrcMsg('IRC messages require a command.')
@@ -90,6 +91,7 @@ class IrcMsg(object):
         self._repr = None
         self._hash = None
         self._len = None
+        self.reply_env = reply_env
         self.tags = {}
         if s:
             originalString = s
@@ -124,6 +126,12 @@ class IrcMsg(object):
                     self.args = args
                 else:
                     self.args = msg.args
+                if reply_env:
+                    self.reply_env = reply_env
+                elif msg.reply_env:
+                    self.reply_env = msg.reply_env.copy()
+                else:
+                    self.reply_env = None
                 self.tags = msg.tags.copy()
             else:
                 self.prefix = prefix
@@ -553,7 +561,7 @@ def kicks(channels, nicks, s='', prefix='', msg=None):
     if isinstance(channels, str): # Backward compatibility
         channels = [channels]
     if conf.supybot.protocols.irc.strictRfc():
-        assert areChannels(channels), repr(channel)
+        assert areChannels(channels), repr(channels)
         assert areNicks(nicks), repr(nicks)
     if msg and not prefix:
         prefix = msg.prefix
@@ -561,11 +569,13 @@ def kicks(channels, nicks, s='', prefix='', msg=None):
         s = s.encode('utf8')
     assert isinstance(s, str)
     if s:
-        return IrcMsg(prefix=prefix, command='KICK',
-                      args=(channel, ','.join(nicks), s), msg=msg)
+        for channel in channels:
+            return IrcMsg(prefix=prefix, command='KICK',
+                          args=(channel, ','.join(nicks), s), msg=msg)
     else:
-        return IrcMsg(prefix=prefix, command='KICK',
-                      args=(channel, ','.join(nicks)), msg=msg)
+        for channel in channels:
+            return IrcMsg(prefix=prefix, command='KICK',
+                          args=(channel, ','.join(nicks)), msg=msg)
 
 def privmsg(recipient, s, prefix='', msg=None):
     """Returns a PRIVMSG to recipient with the message msg."""
